<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>FileView</name>
    <message>
        <location filename="../src/file_view.cpp" line="58"/>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="60"/>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <location filename="../src/file_view.cpp" line="62"/>
        <source>Delete</source>
        <translation>Обриши</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="50"/>
        <source>New recording</source>
        <translation>Нови снимак</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="52"/>
        <source>Open saved directory</source>
        <translation>Отвори место чувања</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="41"/>
        <source>Deepin Voice Recorder is a simple, beautiful and easy to use voice recording application. It supports visual recording, playback, recordings management and other functions.</source>
        <translation>Дипин Снимач Гласа је леп и лак за коришћење програм једноставног дизајна. Подржава визуелно снимање, пуштање снимка, управљање листом снимака и друге функције.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="59"/>
        <source>Deepin Voice Recorder</source>
        <translation>Дипин Снимач Гласа</translation>
    </message>
</context>
<context>
    <name>RecordPage</name>
    <message>
        <location filename="../src/record_page.cpp" line="59"/>
        <location filename="../src/record_page.cpp" line="234"/>
        <source>New recording</source>
        <translation>Нови снимак</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/utils.cpp" line="136"/>
        <source>Recordings</source>
        <translation>Снимци</translation>
    </message>
</context>
</TS>